import pyshorteners

def shortier(linkURL, servProvider=None):

    # match int(input("-- Enter your choice in digits --")):
    # return pyshorteners.Shortener().tinyurl.short(linkURL)
    match servProvider:

        case "chilpit":
            return pyshorteners.Shortener().chilpit.short(linkURL)
        case "clckru":
            return pyshorteners.Shortener().clckru.short(linkURL)
        case "dagd":
            return pyshorteners.Shortener().dagd.short(linkURL)
        case "isgd":
            return pyshorteners.Shortener().isgd.short(linkURL)
        case "osdb":
            return pyshorteners.Shortener().osdb.short(linkURL)
        case "tinyurl":
            return pyshorteners.Shortener().tinyurl.short(linkURL)

    return pyshorteners.Shortener().tinyurl.short(linkURL)


import argparse
from .shortier import shortier

def main():
    parser = argparse.ArgumentParser(
        description="A Link shortener with support for various providers."
    )
    parser.add_argument(
        "linkURL", type=str,
        help="The resource URL to be shortened."
    )

    parser.add_argument(
        "--type", type=str,
        help=("Service used to shorten the URL "
                "if not set, will use tinyurl. "
                "Options include : chilpit, clckru, dagd,isgd,osdb,tinyurl")
    )

    args = parser.parse_args()
    shortenedURL = shortier(args.linkURL, args.type)
    print("Your link is : " + shortenedURL)

if __name__ == "__main__":
    main()


import setuptools

with open("README.md", "r", encoding="utf-8") as fhand:
    long_description = fhand.read()

setuptools.setup(
    name="shortier",
    version="1.1.2",
    author="Yash Kumar",
    author_email="yashkc2025@gmail.com",
    description="A Link shortener with support for various providers.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/yashkc2025/shortier",
    project_urls={
        "Bug Tracker":"https://github.com/yashkc2025/shortier/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=["pyshorteners"],
    packages=setuptools.find_packages(),
    python_requires=">=3.7",
    entry_points={
        "console_scripts": [
            "shortier = shortier.cli:main",
        ]
    },
    
)